@@ -104,10 +104,8 @@ class KubeModel(ABC):
         """
         optimizer = self.configure_optimizers()
         self.optimizer = optimizer
-        if self.epoch > 0:
-            self._load_optimizer_redis()
-        else:
-            self._save_optimizer_redis()
+        self._load_optimizer_redis()
+  
         # TODO here the state loaded should be the averaged one not the saved from earlier
 
         # self._load_optimizer_state()
@@ -164,9 +162,11 @@ class KubeModel(ABC):
         job_id = self.args._job_id
         func_id = self.args._func_id
         weight_key = f'{job_id}:optimizer:{func_id}' 
-        pickled_val = self._redis_client.get(weight_key)
-        opt_states = pickle.loads(pickled_val)  
-        self.optimizer.load_state_dict(opt_states)
+
+        if  self._redis_client.exists(weight_key):
+            pickled_val = self._redis_client.get(weight_key)
+            opt_states = pickle.loads(pickled_val)  
+            self.optimizer.load_state_dict(opt_states)
 
     def _get_logger(self):
         """
